// Copyright (c) 2021 Julien Floret
// Copyright (c) 2021 Robin Jarry
// SPDX-License-Identifier: BSD-3-Clause

a.user-repo,
a.tag,
a.branch,
a.product-branch,
a.variant,
a.version,
a.product,
a.job {
  font-family: $font_mono;
  border-width: 1px;
  border-radius: 0.25rem;
  border-color: $lightgray;
  padding: $padding * 2;
  background-color: $white;
  margin: 0.2rem;
  display: block;
}

a.user-repo:hover,
a.tag:hover,
a.branch:hover,
a.product-branch:hover,
a.variant:hover,
a.version:hover,
a.product:hover,
a.job:hover {
  background-color: lighten($lightgray, 5%);
}

a.product {
  padding: $padding;
}

a.product > img {
  display: inline;
  margin-right: $padding / 2;
  height: 1.8rem;
}

a.product-xl {
  font-size: 1.1rem;
}

a.product-xl > img {
  display: inline;
  margin-right: $padding;
  height: 2.4rem;
}

a.alias {
  font-style: italic;
  color: lighten($darkgray, 30%);
}

a.released,
a.locked {
  background-repeat: no-repeat;
  background-attachment: local;
  background-position: calc(100% - 1rem) center;
  padding-right: 2rem;
  background-size: 0.7rem;
}

a.released {
  background-color: $released;
  background-image: url(/static/released.svg);
}

a.released:hover {
  background-color: darken($released, 5%);
}

a.released.published {
  background-image: url(/static/published.svg);
}

a.locked {
  background-color: $locked;
  background-image: url(/static/locked.svg);
}

a.locked:hover {
  background-color: darken($locked, 5%);
}
